@@ -39,3 +39,16 @@ fn disassemble() {
 
     assert_eq!(data, snowflake.disassemble(6828242137746771969))
 }
+
+#[test]
+fn custom_options() {
+    let snowflake = Snowflake::new(0, 2, 1);
+    let data = SnowflakeData {
+        timestamp: 1628867112448,
+        worker_id: 2,
+        node_id: 1,
+        sequence: 1,
+    };
+
+    assert_eq!(data, snowflake.disassemble(6831963845209362433))
+}
